import { Identifiable, Multilingual, Stateful } from "@/data/common";

interface PredefinedChoices {
    choices: Multilingual<string>[];
}

export interface BaseFieldDefinition extends Identifiable {
    description: Multilingual<string>;
    label: Multilingual<string>;
}

export interface TextFieldDefinition extends BaseFieldDefinition {
    type: "short-text" | "long-text";
}

export type TextFieldValue = string;

export interface MultiChoiceFieldDefinition extends BaseFieldDefinition, PredefinedChoices {
    type: "checkbox";
}

export type MultiChoiceValue = Multilingual<string>[];

export interface SingleChoiceFieldDefinition extends BaseFieldDefinition, PredefinedChoices {
    type: "radio" | "select";
}

export type SingleChoiceValue = Multilingual<string>;

export type ReportFieldDefinition = TextFieldDefinition | MultiChoiceFieldDefinition | SingleChoiceFieldDefinition;
export type ReportFieldValue = TextFieldValue | MultiChoiceValue | SingleChoiceValue;
export type ReportFieldValues = { [field: string]: ReportFieldValue };
export type ReportSchema = ReportFieldDefinition[];
export type ReportFieldType = ReportFieldDefinition['type'];

export interface Report extends Stateful, Identifiable {
    fields: ReportFieldValues;
}

export const reportFieldTypes: ReportFieldType[] = ["short-text", "long-text", "checkbox", "radio", "select"];

