import { Course } from "@/data";
import { axios } from "@/api";
import { CourseDTO, courseDtoTransformer } from "@/api/dto/course";
import { encapsulate, OneOrMany } from "@/helpers";
import { prepare } from "@/routing";

const COURSE_INDEX_ENDPOINT = '/management/course'
const COURSE_ENDPOINT = COURSE_INDEX_ENDPOINT + "/:id";

export async function all(): Promise<Course[]>  {
    const response = await axios.get<CourseDTO[]>(COURSE_INDEX_ENDPOINT);
    return response.data.map(dto => courseDtoTransformer.transform(dto))
}

export async function remove(type: OneOrMany<Course>): Promise<void> {
    await Promise.all(encapsulate(type).map(
        type => axios.delete(prepare(COURSE_ENDPOINT, { id: type.id as string }))
    ));
}

export async function save(type: Course): Promise<Course> {
    await axios.put<Course>(
        COURSE_INDEX_ENDPOINT,
        courseDtoTransformer.reverseTransform(type)
    );

    return type;
}
