import { axios } from "@/api";
import { EditionDTO, editionDtoTransformer, editionUpdateDtoTransformer } from "@/api/dto/edition";
import { Edition } from "@/data/edition";
import { prepare } from "@/routing";

const MANAGEMENT_EDITION_INDEX_ENDPOINT = '/management/editions';
const MANAGEMENT_EDITION_ENDPOINT = '/management/editions/:edition';

export async function all(): Promise<Edition[]> {
    const response = await axios.get<EditionDTO[]>(MANAGEMENT_EDITION_INDEX_ENDPOINT);
    return response.data.map(dto => editionDtoTransformer.transform(dto));
}

export async function details(edition: string): Promise<Edition> {
    const response = await axios.get<EditionDTO>(prepare(MANAGEMENT_EDITION_ENDPOINT, { edition }));
    return editionDtoTransformer.transform(response.data);
}

export async function save(edition: Edition): Promise<boolean> {
    const response = await axios.put<EditionDTO>(
        MANAGEMENT_EDITION_INDEX_ENDPOINT,
        editionUpdateDtoTransformer.transform(edition),
    );

    return response.status == 200;
}
