import { InternshipType } from "@/data";
import { axios } from "@/api";
import { InternshipTypeDTO, internshipTypeDtoTransformer } from "@/api/dto/type";
import { encapsulate, OneOrMany } from "@/helpers";
import { prepare } from "@/routing";

const INTERNSHIP_TYPE_INDEX_ENDPOINT = '/internshipTypes'
const INTERNSHIP_TYPE_ENDPOINT = INTERNSHIP_TYPE_INDEX_ENDPOINT + "/:id";

export async function all(): Promise<InternshipType[]>  {
    const response = await axios.get<InternshipTypeDTO[]>(INTERNSHIP_TYPE_INDEX_ENDPOINT);
    return response.data.map(dto => internshipTypeDtoTransformer.transform(dto))
}

export async function remove(type: OneOrMany<InternshipType>): Promise<void> {
    await Promise.all(encapsulate(type).map(
        type => axios.delete(prepare(INTERNSHIP_TYPE_ENDPOINT, { id: type.id as string }))
    ));
}

export async function save(type: InternshipType): Promise<InternshipType> {
    await axios.put<InternshipType>(
        INTERNSHIP_TYPE_INDEX_ENDPOINT,
        internshipTypeDtoTransformer.reverseTransform(type)
    );

    return type;
}
