import { SubmissionStatus } from "@/state/reducer/submission";
import { createStyles, makeStyles } from "@material-ui/core/styles";
import { Theme, Tooltip } from "@material-ui/core";
import { green, orange, red } from "@material-ui/core/colors";
import React, { HTMLProps } from "react";
import { useTranslation } from "react-i18next";
import classNames from "classnames";
import { stateIcons } from "@/management/edition/proposal/common";
import { Remove } from "@material-ui/icons";
import { Close } from "mdi-material-ui";

const useStyles = makeStyles((theme: Theme) => createStyles({
    "root": {
        borderWidth: "2px",
        borderStyle: "solid",
        borderRadius: "100%",
        padding: "0.25rem",
        display: "inline-block",
        width: "2.25rem",
        height: "2.25rem",
        textAlign: "center",
        position: "relative",
        transform: "scale(0.8)"
    },
    "icon": {
        position: "absolute",
        bottom: "-12px",
        right: "-12px",
        fontSize: "0.25rem",
        backgroundColor: "white",
        borderRadius: "100%",
        transform: "scale(0.75)",
        padding: "3px",
    },
    awaiting: {
        borderColor: theme.palette.primary.main,
        color: theme.palette.primary.main,
    },
    declined: {
        borderColor: red["600"],
        color: red["600"],
    },
    draft: {},
    accepted: {
        borderColor: green["600"],
        color: green["600"]
    }
}))

export type StepStateProps = {
    state: SubmissionStatus | null;
    label: string;
    icon: React.ReactChild,
} & HTMLProps<HTMLDivElement>;

export const StepState = ({ label, state, icon, ...props }: StepStateProps) => {
    const { t } = useTranslation();
    const classes = useStyles();

    return <Tooltip title={`${label} - ${t(`submission.status.${state || "empty"}`)}`}>
        <div className={ classNames(classes.root, state && classes[state]) } { ...props }>
            { icon }
            <div className={ classes.icon }>
                { state ? stateIcons[state] : <Close /> }
            </div>
        </div>
    </Tooltip>
}
