import React, { useCallback, useEffect } from "react";
import { Dialog, DialogActions, DialogContent, DialogProps, DialogTitle } from "@material-ui/core";
import { fullname, Internship, Student } from "@/data";
import { ProposalPreview } from "@/components/proposalPreview";
import { AcceptanceActions } from "@/components/acceptance-action";
import { InternshipSubmission } from "@/management/api/internship";
import api from "@/management/api";
import { useAsync, useAsyncState } from "@/hooks";
import { Async } from "@/components/async";

export type InternshipDetailsDialogProps = {
    internship: InternshipSubmission;
    onAccept: (comment?: string) => void;
    onDiscard: (comment: string) => void;
} & DialogProps;

export const InternshipDetailsDialog = ({ internship, onAccept, onDiscard, ...props }: InternshipDetailsDialogProps) => {
    const [ details, setPromise ] = useAsyncState();

    useEffect(() => {
        if (props.open) {
            setPromise(api.internship.get(internship.id as string));
        }
    }, [ props.open, internship.id ])

    return <Dialog maxWidth="lg" fullWidth { ...props }>
        <DialogTitle>{ fullname(internship.intern as Student) }</DialogTitle>
        <DialogContent>
            <Async async={details}>{ internship => <ProposalPreview proposal={ internship as Internship }/> }</Async>
        </DialogContent>
        <DialogActions>
            <AcceptanceActions onAccept={ onAccept } onDiscard={ onDiscard } label="internship"/>
        </DialogActions>
    </Dialog>
}
