import { Button, Dialog, DialogActions, DialogContent, DialogProps, DialogTitle } from "@material-ui/core";
import React from "react";
import { Form, Formik } from "formik";
import { initialStaticPageFormValues, StaticPageForm, StaticPageFormValues, staticPageFormValuesTransformer } from "@/management/page/form";
import { Actions } from "@/components";
import { Save } from "@material-ui/icons";
import { useTranslation } from "react-i18next";
import { Cancel } from "mdi-material-ui";
import { useSpacing } from "@/styles";
import { default as StaticPage } from "@/data/page";

export type EditStaticPageDialogProps = {
    onSave?: (page: StaticPage) => void;
    page?: StaticPage;
} & DialogProps;

export function EditStaticPageDialog({ onSave, page, ...props }: EditStaticPageDialogProps) {
    const { t } = useTranslation("management");
    const spacing = useSpacing(3);

    const handleSubmit = (values: StaticPageFormValues) => {
        onSave?.(staticPageFormValuesTransformer.reverseTransform(values));
    };

    const initialValues = page
        ? staticPageFormValuesTransformer.transform(page)
        : initialStaticPageFormValues;

    return <Dialog { ...props } maxWidth="lg">
        <Formik initialValues={ initialValues } onSubmit={ handleSubmit }>
            <Form className={ spacing.vertical }>
                <DialogTitle>{ t(page ? "page.edit.title" : "page.create.title") }</DialogTitle>
                <DialogContent>
                    <StaticPageForm />
                </DialogContent>
                <DialogActions>
                    <Actions>
                        <Button variant="contained" color="primary" startIcon={ <Save /> } type="submit">{ t("save") }</Button>
                        <Button startIcon={ <Cancel /> } onClick={ ev => props.onClose?.(ev, "escapeKeyDown") }>{ t("cancel") }</Button>
                    </Actions>
                </DialogActions>
            </Form>
        </Formik>
    </Dialog>
}

